Module app

Module app 

Structs

App
RepoTab
All state that belongs to a single repository tab.
StagingPayload
Payload returned by an async staging refresh.

Enums

ActivePane
AppScreen
BackgroundResult
Results produced by background tasks and sent back to the main loop.
DiffSubPane
Which half of the split Diff pane currently has keyboard focus.
InputMode
InputPurpose
StagingFocus
Which sub-list within the staging pane has focus.

Type Aliases

RepoPayload
Alias for the shared core type — kept for backward-compat with the BackgroundResult::RepoLoaded variant.